import java.io.*;
import java.net.Socket;
import java.time.LocalDate;
import java.time.LocalTime;
import java.time.format.DateTimeFormatter;

public class ClientHandler implements Runnable {
    private final Socket socket;
    private final int clientNum;
    private final DateTimeFormatter timeFormatter;
    private BufferedReader input;
    private PrintWriter output;

    public ClientHandler(Socket socket, int client) {
        this.socket = socket;
        this.clientNum = client;
        this.timeFormatter = DateTimeFormatter.ofPattern("HH:mm:ss");
    }

    @Override
    public void run() {
        try {
            input = new BufferedReader(
                    new InputStreamReader(socket.getInputStream()));
            output = new PrintWriter(socket.getOutputStream(), true);

            output.println("This is simple time server. " +
                    "Possible commands are: time/date/UTC");

            process();

        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            try {
                input.close();
                output.close();
                
                socket.close();
                System.out.printf("Client [%d] disconnected%n", clientNum);
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
    }

    private void process() throws IOException {
        String inputLine;
        while ((inputLine = input.readLine()) != null) {
            System.out.printf(" > Message received from client [%d]: %s%n",
                                clientNum, inputLine);

            switch (inputLine) {
                case "time":
                    output.println("Time: " + LocalTime.now().format(timeFormatter));
                    break;
                case "date":
                    output.println("Date: " + LocalDate.now());
                    break;
                case "UTC":
                    output.println("UTC: " + System.currentTimeMillis());
                    break;
                default:
                    output.println("Invalid command! Possible commands are: time/date/UTC");
                    break;
            }
        }
    }
}
